{% extends "admin/change_form.html" %}
{% load i18n %}
{% block object-tools %}
    {{ block.super }}
    {% if time_zone %}
        <div id="time_zone" style="display:none" value="{{time_zone}}"></div>
    {% endif %}
{% endblock %}
