{% extends "admin/change_list.html" %}

{% block content %}
    {{ block.super }}
    {% if time_zone %}
        <div id="time_zone" style="display:none" value="{{time_zone}}"></div>
    {% endif %}
{% endblock %}
