{% load i18n %}
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">


<html xmlns="http://www.w3.org/1999/xhtml"
    lang="{{ LANGUAGE_CODE }}"
    xml:lang="{{ LANGUAGE_CODE }}"
    {% if LANGUAGE_BIDI %}dir="rtl"{% endif %}>

<head>

<title>OpenProximity 2.0 {% block title %}{% endblock %}</title>

<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/openproximity.css" />

{% comment %}
This is the only css in the code, as it reflects configurable settings
{% endcomment %}
<style type="text/css">
    .logo {
        background: url({{ STATIC_URL }}images/{% if settings.logo %}{{ settings.logo }}{% else %}logo.gif{% endif %}) no-repeat;
    }
</style> 

{% block style %}
{% endblock %}

<script type="text/javascript" src="{{ STATIC_URL }}js/jquery-1.6.2.min.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}js/jquery.vertical.align.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}js/jquery.center.packed.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}js/openproximity.js"></script>
{% block extrahead %}{% endblock %}
</head>

<body id="{% block bodyid %}page{% endblock %}">
<div class="content">
{% block content %}{% endblock %}
</div>
<div class="footer">
    {% block footer %}{% endblock %}
<p><a class="close-window" href="javascript:%20self.close()">{% trans "Close this Window"%}</a></p>
<p><a href="http://code.google.com/p/proximitymarketing/">OpenProximity 2.0</a> Powered by <a href="http://www.aircable.net">AIRcable.net</a></p>
</div>
</body>
</html>
