{% load i18n %}

{% if user.is_authenticated %}
    <li class="username">
        <span>{% trans 'Welcome,' %} <strong>{% firstof user.first_name user.username %}</strong></span>
    </li>
    <li>
        <a href="/accounts/password_change">{% trans "Change password" %}</a>
    </li>
    <li>
        <a href="/accounts/logout">{% trans "Log out" %}</a>
    </li>
{% else %}
    <li class="username">
        <span>{% trans 'Welcome,' %} <strong>{% trans 'Anonymous' %}</strong></span>
    </li>
    <li>
        <a href="/accounts/login/">{% trans "Log in" %}</a>
    </li>
{% endif %}

