{% extends "op/base.html" %}

{% load i18n microblog %}
{% load openproximity %}
{% settings %}

{% block extrahead %}
{% comment %} field line content refresh 'amount to show' 'first read' {% endcomment %}
{% Tweet 'messages' 'fields.time' './microblog' 'post.fields.time.split(\' \')[1] + " " + post.fields.content + "\n"' 5 15 %}

<script src="{{ STATIC_URL }}js/jquery.tweet.js" type="text/javascript"></script>
{% endblock %}

{% block bodyid %}main-page{% endblock %}

{% block content %}
    <table id="main-content" cellspacing="0" cellpadding="0" class="layout-grid">
        <tbody>
            <!--tr>
                <td class="holder corners" id="new_version_top" colspan="3" />
            </tr>
            <tr class="spacer" /-->
            <tr>
                <td style="width: 50%" class="holder corners">
                    {% include "op/imports/server_stats.html" %}
                </td>
                <td class="spacer" rowspan="3" />
                <td rowspan="3" class="holder corners">
                    <h1>{% trans "Server Log" %}</h1>
                    <div id="messages"></div>
                </td>
            </tr>
            <tr class="spacer" />
            <tr>
                <td class="holder corners">
                    {% include "op/imports/server_status.html" %}
                </td>
            </tr>
            <tr class="spacer" />
            <tr>
                <td colspan="3" class="holder corners">
                    {% include "op/imports/known_dongles.html" %}
                </td>
            </tr>
            <tr class="spacer" />
            <tr>
                <td colspan="3" class="holder corners">
                    {% include "op/imports/campaigns.html" %}
                </td>
            </tr>
            <tr class="spacer" />
        </tbody>
    </table>
{% endblock %}

{% block footer %}
{% endblock %}

{% if settings.twitter %}
    {% block right_sidebar %}
        <div id="tweets-holder" class="corners">
            <h1 class="header">Tweets from AIRcable.net</h1>
            <div id="tweets">
                <div class="aircable_manuel"></div>
                <div class="aircable_net"></div>
            </div>
        </div>
    {% endblock %}
{% endif %}

