/* ------- Page Layout ------- */
body { 
    background:#369; 
    color:#333; 
    font:76%/1.6 "Lucida Grande","Bitstream Vera Sans",Verdana,sans-serif; 
    padding: 0;
    margin: 0px;
    height: 100%;
}

.navigation {
//    margin-top: 2.3em;
//    margin-left: 3em;
//    margin-right: 3em;
    //height: 60px;
//    float: bottom;
    border: none;
    padding: 0px;
}

.header, .header-top {
    display: inline-block;
}

.logo {
    float: left;
}

.content{
    min-height: 100%;
    height: auto !important;
    height: 100%;
    margin-left: 3em;
    margin-right: 3em;
    margin-top: 0.5em;
    vertical-align: bottom;
    float: bottom;
}

/* FOOTER */
.footer { 
    margin-right: 3em;
    margin-left: 3em;
    margin-bottom: 3m;
    background: #e4e4e4; 
}

h1 { 
    font-size:1.8em; 
    color:#666; 
    margin:0.4em 0 0.2em 0; 
}

h2 { 
    font-size:1.5em; 
    color:#666; 
    margin:1em 0 0.2em 0; 
}

p { margin:0.5em 0 1em 0; }

a { color: #5b80b2; 
    text-decoration: none; 
}

a:hover { text-decoration: underline; }

a img { border: none; }

/* building blocks for content screens */
.content-main {
    background: #e4e4e4;
    margin-bottom: 1em;
    font-size: 12px;
    float: bottom;
}

.content-main h1{
    margin: 0;
    font-size: 12px;
}

.inner {
    padding: 0.5em
}

/* NAVIGATION */
.logo {
    float: left; 
    width: 206px; 
    height: 66px; 
}
#nav { 
    padding: 0; 
    /* overflow: hidden; */
    height: 66px; 
}

.nav_button { 
    overflow: hidden;
    padding-bottom: 1 em;
    margin-left: 0.5em;
    float: left;
    width: 110px; 
    height: 66px;
    text-align: center; 
    text-decoration: none; 
    text-transform: uppercase; 
    background-color: #a6d5e9;
    color: #555; 
    white-space: nowrap;
    text-decoration: none;
}

.nav_button_grey { 
    overflow: hidden;
    padding-bottom: 1 em;
    margin-left: 0.5em;
    float: left;
    width: 110px; 
    text-align: center; 
    text-decoration: none; 
    background-color: #a6d5e9;
    color: #555; 
    white-space: nowrap; 
    
    text-decoration: none;
}


.nav_button .inner {
    height: 56px;
    padding: 0px;
}

.btn { 
    overflow: hidden;
    padding-bottom: 0.5 em;
    background-color: #a6d5e9;
    color: #555; 
    white-space: nowrap; 
    text-decoration: none;
    position: absolute;
    bottom: 0.5em;
    right: 1em;
}


*.table { 
    snap: 1 ; 
    border: 1
}

.footer p { 
    margin: 0; 
    padding: 3px 0; 
}

.up {
    border-right: 1px solid #999;
    border-bottom: 1px solid #666;
}

.down {
    /* border-top: 1px solid #666;
    border-left: 1px solid #999; */
}

.userinfo {
    font-size: 11px;
    text-align: right;
    background-color: #a6d5e9;
    position: absolute;
    left: 3.4em;
    top: 0em;
}

/*.plugins {
    font-size: 11px;
    text-align: right;
    background-color: #a6d5e9;
    position: absolute;
    right: 3em;
    top: 0em;
}*/


/* KNOWN TABLE */
table.known { 
    padding: 0.5em;
    border: 0;
    cellspacing: 0;
    background-color: white;
}

table.known td {
    padding: 5px;
    border-color: gray;
}

/* op classes */
.leftpanel{
    position:relative;
    float: left;
    margin: 1em;
    width: 40%;
}

.server .stats{
/*    padding-left: 1em; */
    /* width: %;*/
    position: relative;
}

.log {
    /* height: 600px; */
}

.rest {
    float: bottom;
}

.label {
    float: left;
    width: 20em;
    font-weight: bold;
}

.value {
    width: 100%;
}

.setting {
    float: bottom;
}

.tree-default-context a ins.refresh { 
    background-position:0 0; 
    background: url(/static/images/view-refresh.png);
}
