#dock .username span, 
        #dock .plugins span {
    font-size: 12px;
    color: #CCC;
    border-bottom: 2px solid #FF9C08;
    padding: 0 5px;
    line-height: 22px;
    float: left;
    text-decoration: none;
}

h1.logo {
    top: 0px;
    left: 0px;
}

body {
    background: #369;
}

#navigation {
    top: 30px;
}

#banner {
    height: 75px;
}

#footer .aircablesmall {
    background: url("http://www.aircable.net/images/logo/aircable/aircable-logo.png");
    width: 180px;
    height: 56px;
    border: 0;
    margin: 3px 22px 0px 3px;
}

#footer .aircable img {
    width:  auto;
    height: 35px;
    border: 0;
    margin: 0px 22px 0px 3px;
}

#right-sidebar {
    position: absolute;
    clear: both;
    right: 5px;
    width: 145px;
    top: 95px;
    bottom: 5px;
}

#tweets {
    padding-bottom: 5px;
}

#tweets-holder {
    color: white;
    background: lightblue;
}

#tweets-holder h1 {
    padding-left: 10px;
    padding-right: 10px;
    padding-top: 5px;
}

#tweets ul {
    padding: 0px;
    margin: 0px;
    list-style: none;
    border: none;
}

#tweets li {
    border-bottom: 1px solid #90bade;
    margin: 0px 6px;
    clear: both;
}

#tweets .tweet_even {
    background: #8DD8E6;
    color: white;
}

#tweets .tweet_avatar {
    float: left;
}

#footer .version {
    width: 50%;
}

#main-content .holder {
    background: lightblue;
    padding: 15px;
    //border: 2px solid black;
}

#main-content td.spacer {
    width: 20px;
}

#main-content tr.spacer {
    height: 20px;
}

#content, #content .content {
    background: none;
}

#wrapper {
    margin: 0 180px 0 auto;
}

.button {
    background: white;
    width: auto;
    border: 1px solid black;
    padding: 3px 20px;
    text-align: center;
    font-size: 14px;
    cursor: pointer;
}

#loading {
    display: none;
    z-index: 1000;
    width: 200px;
    height: 100px;
    margin: auto;
    border: 1px solid black;
    background-color: gray;
    position: absolute;
    margin: 45%;
}

#loading h1 {
    text-align: center;
    margin-top: 30px;
}

@media screen and (max-width: 1280px) {
    /* fit into smaller screens */
    
    #navigation {
        top: 80px;
        clear: both;
        left: 0px;
    }
    
    #banner {
        height: 110px;
    }
    
    #wrapper {
        width: 90%;
        margin: 0 auto;
    }
    
    #right-sidebar {
        right: -105px;
        top: 130px;
    }
}

