{% load i18n %}
<div class="dongles">
    <h1>{% trans "Known Dongles" %}</h1>
    <div class="rounded-white known">
    <table id="known" class="known" style="width:100%">
        <thead>
            <tr>
            <td>{% trans "Address" %}</td>
            <td>{% trans "Is Scanner" %}</td>
            <td>{% trans "Scanner Enabled" %}</td>
            <td>{% trans "Scanner Priority" %}</td>
            <td>{% trans "Is Uploader" %}</td>
            <td>{% trans "Uploader Enabled" %}</td>
            <td>{% trans "Max Connections" %}</td>
            <td></td>
            </tr>
        </thead>
        <tbody>
            <tr><td></td></tr>
        </tbody>
    </table>
    </div>
</div>
