<!DOCTYPE html 
    PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
{% load i18n openproximity %}
{% plugins %}
<html xmlns="http://www.w3.org/1999/xhtml" 
    lang="{{ LANGUAGE_CODE }}" 
    xml:lang="{{ LANGUAGE_CODE }}" 
    {% if LANGUAGE_BIDI %}dir="rtl"{% endif %}>
<head>
<title>OpenProximity 2.0 {% block title %}{% endblock %}</title>


<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/openproximity.css" />
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/base.css" />
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/openproximity2.css" />
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/cupertino/jquery-ui-1.8.16.custom.css" />

<style type="text/css">
    h1.logo, h1.logo a {
        background: url({{ STATIC_URL }}images/{% if settings.logo %}{{ settings.logo }}{% else %}logo.gif{% endif %}) no-repeat;
        height: 66px;
        width: 206px;
    }
</style>

{% block style %}
{% endblock %}

<script type="text/javascript" src="{{ STATIC_URL }}js/jquery-1.6.2.min.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}js/jquery-ui-1.8.16.min.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}js/jquery.corner.js"></script>
<!-- script type="text/javascript" src="{{ STATIC_URL }}js/jquery.vertical.align.js"></script -->
<!-- script type="text/javascript" src="{{ STATIC_URL }}js/jquery.center.packed.js"></script -->
<!-- script type="text/javascript" src="{{ STATIC_URL }}js/jquery.valign.js"></script -->
<script type="text/javascript" src="{{ STATIC_URL }}js/openproximity.js"></script>

<script type="text/javascript">
    // translate strings
    LOADING = "{% trans "Loading" %}";
    REFRESH = "{% trans "Refresh" %}";
    DELETE = "{% trans "Delete" %}";
    DELETE_MSG = "{% trans "You sure you want to delete?" %}";
    ADMIN_LOG = "{% trans "You need to be loged as admin first" %}";
    CONFIGURE = "{% trans "Configure" %}";
    SERVER_VERSION = "{% trans "server version" %}";
    RUNNING_VERSION = "{% trans "running version" %}";
    NEW_VERSION_AVAILABLE = "{% trans "There's a new version available" %}";
    NEW_VERSION = "{% trans "New Version" %}";
    YOUR_VERSION = "{% trans "Your Version" %}";

    // replacesable strings
    current_version = "{{ version.current }}";
</script>

{% block extrahead %}{% endblock %}
</head>

<body id="{% block bodyid %}page{% endblock %}">
    <div id="loading">
        <h1>{% trans "Loading..." %}</h1>
    </div>
    <div id="wrapper">
        <div id="banner">
            <h1 class="logo">
                <a href="http://www.aircable.net" title="AIRcable.net"><span>AIRcable.net</span></a>
            </h1>
            <div id="dock">
                <div class="left"></div>
                <ul>
                    {% include "op/imports/userinfo.html" %} <!-- login information -->
                    {% include "op/imports/plugins.html" %} <!-- plugins information -->
                </ul>
                <div class="right"></div>
            </div>
            
            <div id="navigation">
                <div class="left"></div>
                <ul>
                    <li>
                        <a id="nav_index" href="/">{% trans "Index" %}</a>
                    </li>
                    {% block navbar %}
                        <li>
                            <a id="nav_documentation" 
                                href="javascript: popitup('http://wiki.openproximity.org/userdocumentation', '')"
                                >{% trans "Documentation" %}</a>
                        </li>
                        <li>
                            <a id="nav_last_seen"
                                href="javascript: popitup('/last-seen/', '')"
                                >{% trans "Last Seen" %}</a>
                        </li>
                        {% if settings.debug %}
                            <li>
                                <a id="nav_data" href="/data/">{% trans "Data Browse" %}</a>
                            </li>
                            <li>
                                <a id="nav_treeview" href="/treeview">{% trans "Data Tree" %}</a>
                            </li>
                        {% endif %}
                        <li {% if not settings.translate %} class="last" {% endif %}>
                            <a id="nav_admin" href="/admin/openproximity">{% trans "Admin Site" %}</a>
                        </li>
                        {% if settings.translate %}
                            <li class="last">
                                <a id="nav_translate" href="javascript: popitup('/admin/translate')">{% trans "Translate" %}</a>
                            </li>
                        {% endif %}
                    {% endblock %}
                </ul>
                <div class="right"></div>
            </div>
        </div>
    
        <div id="content-wrapper"> 
            <div id="content">
                {% block content %}{% endblock %}
            </div>
        </div>
        

        <div id="footer">
            <div class="bg"></div>
            <div class="inner">
                <p>
                    <span class="first">Sponsored by: </span>
                    <a class="block aircable" href="http://www.aircable.net">
                        <img src="http://www.aircable.net/images/logo/aircable/aircable-logo.png" />
                    </a>
                   
                    {% block footer %}{% endblock %}
                    <span class="version first"></span>
                    
                    <span class="first" style="float: right; padding-right: 12px;">                      
                        © 2011, 2008 <a href="http://code.google.com/p/proximitymarketing/">OpenProximity 2.0</a>
                    </span>
                </p>
            </div>
        </div>
    </div>

    <div id="right-sidebar">
        {% block right_sidebar %}{% endblock %}
    </div>

</body>

<!--script type="text/javascript" src="http://proximitymarketing.googlecode.com/svn/trunk/openproximity2/latest-version.js"></script-->

</html>
