{% extends "op/base_popup.html" %}
{% load i18n %}

{% block extrahead %}
<script type="text/javascript">
    addLoadEvent(update_seen_table);
    setInterval("update_seen_table()", 30*1000); //update each 30 secs
</script>
{% endblock %}

{% block bodyid %}last-seen{% endblock %}

{% block content %}
<div class="content-main"><div class="inner">
<b>{% trans "Devices seen during the last 15 minutes" %}</b>
<table id="last_seen">
    <thead>
	<tr>
	    <td>{% trans "Address" %}</td>
	    <td>{% trans "Name" %}</td>
	    <td>{% trans "Last Seen" %}</td>
	    {% comment %}<td>{% trans "Devclass" %}</td>{% endcomment %}
	    <td>{% trans "Obex Valid" %}</td>
	    {% comment %}<td>{% trans "Tried" %}</td>{% endcomment %}
	    <td>{% trans "Timeout" %}</td>
	    <td>{% trans "Rejected" %}</td>
	    <td>{% trans "Accepted" %}</td>
	</tr>
    </thead>
    <tbody id="last_seen_body"><tr><td/></tr></tbody>
</table>
</div></div>

{% endblock %}
