{% extends "op/base.html" %}
{% load i18n %}

{% block bodyid %}treeview{% endblock %}
{% block extrahead %}
<script type="text/javascript" src="{{ STATIC_URL }}js/jquery.jstree.js"></script>
<!--script type="text/javascript" 
    src="{{ STATIC_URL }}js/plugins/jquery.tree.contextmenu.js"></script-->

<script type="text/javascript">
    LOADING="{% trans "Loading" %}";
    REFRESH="{% trans "Refresh" %}";
    DELETE="{% trans "Delete" %}";
    DELETE_MSG="{% trans "You sure you want to delete?" %}";
    ADMIN_LOG="{% trans "You need to be loged as admin first" %}";
</script>

{% endblock %}

{% block content %}
    <div class="content-main">
        <fieldset style="margin: 0px; padding: 0px; border: none">
    	    <div class="inner">
	        <div id="async_tree"></div>
	    </div>
	</fieldset>
    </div>
{% endblock %}

