{% load i18n %}
<div class="server" id="rpc">
    <fieldset>
        <legend>{% trans "Server Status" %}</legend>
        <div class="setting">
            <div class="label">{% trans "RPC Server is running" %}</div>
            <span class="value" id="rpc_running">{{ rpc.running|yesno:_("yes,no") }}</span>
        </div>
        <div class="setting">
            <div class="label">{% trans "Uploaders Connected" %}</div>
            <span class="value" id="rpc_uploadres">{{ rpc.uploaders }}</span>
        </div>
        <div class="setting">
            <div class="label">{% trans "Scanners Connected" %}</div>
            <span class="value" id="rpc_scanners">{{ rpc.scanners }}</span>
        </div>
        {% if rpc.error %}
            <div class="setting error" id="error">
                <div class="label">{% trans "Error Message" %}</div>
                <span class="value" id="error">{{ rpc.error }}</span>
            </div>
        {% endif %}
        <div class="button corners" id="reset-server" onclick="reset_server();">
            {% trans "Reset RPC Server" %}
        </div>
    </fieldset>
</div>