{% load i18n openproximity %}
{% plugins %}

{% if plugins %}
    <li class="plugins">
        <span>{% trans "Plugins" %}</span>

	    <select style="border: none" onchange="window.location.href=this.value" id="plugins_list">
        	<option value="/">----------------------</option>
            	{% for plugin in plugins %}
        		<option value="/{{ plugin.provides.urls.0 }}/" >{{ plugin.name }}</option>
            	{% endfor %}
	    </select>
    </li>
{% endif %}

