/* this classes are needed for databrowse to work */

/* BREADCRUMBS */
#breadcrumbs { 
    padding:10px; 
    color:#999; 
    font-size:0.9em; 
}

.stat { font-size:20em; }
.odd { background-color:#EDF3FE; }
.quiet { color:#666; }

/* FILTERS */
.filter { 
    color:#999; 
    font-size:0.9em; 
    float:left; 
    margin-bottom:10px; 
    margin-right:20px; 
}
.filter strong { color:#666; }

/* OBJECT LISTS */
.objectlist { 
    clear:both; 
    margin:0 -20px; 
    color:#666; 
    /*word-break:break-all;*/
}
.objectlist li a { 
    display:block; 
    padding:1em 20px; 
}
.objectlist li a:hover { 
    background:#5b80b2; 
    color:#3B5572; 
    color:#fff; 
    text-decoration:none; 
}
.related h2 { 
    font-size: 1em; 
    margin-bottom: 0.6em; 
}
.related .objectlist li a { 
    padding: 0.6em 20px; 
}
.related .objectlist li.odd { 
    background:#eee; 
}

/* OBJECT DETAIL */
.objectinfo { 
    border-collapse:collapse; 
    color:#666; 
    margin:0 -20px; 
/*    word-break:break-all;*/
}
.objectinfo td, .objectinfo th { 
    padding:1em 20px; 
    vertical-align:top; 
}
.objectinfo td { 
    width:100%; 
}
.objectinfo th { 
    text-align:left; 
    white-space:nowrap; 
}

/* MODEL GROUPS */
.modelgroup { 
    color:#999; 
    font-size:0.9em; 
    margin:0 -0.5em; 
/*    word-break:break-all; */
}
.modelgroup h2 { 
    font-size:1.2em; 
    margin:0; 
}
.modelgroup h2 a { 
    display: block; 
    padding: 0.83em 20px; 
}
.modelgroup h2 a:hover { 
    text-decoration: none; 
    color: #fff; 
}
.modelgroup p { 
    float:left; 
    margin:-2.65em 0 0 30em; 
    position:relative; 
/*    word-break:break-all;*/
}
.modelgroup p a { 
    white-space:nowrap; 
/*    word-break:break-all*/
}
.modelgroup a.more { 
    color:#999; 
}
.modelgroup:hover { 
    background:#5b80b2; 
    color:#becfe5; 
}
.modelgroup:hover p a { 
    color:#becfe5; 
}
.modelgroup:hover a { 
    color:#fff; 
}
.modelgroup:hover a.more { 
    color:#fff; 
}
