{% extends "op/base.html" %}
{% load i18n %}
{% block title %}| {% trans "Configure Dongle" %}{% endblock %}
{% block bodyid %}dongle-form{% endblock %}
{% block content %}
<div class="content-main"><div class="inner">
{% if form.errors %}
<h1>{% trans "Errors while configuring" %}</h1>
<p id="error">
    {% trans "Please Correct" %}{{ form.errors|pluralize }}.
</p>
{% endif %}
<form action="." method="post">
    <table>
	{{ form.as_table }}
	<tr>
	    <td><input type="submit" value="{% trans "Configure" %}"></td>
	</tr>
    </table>
<p id="success">
	{% if messages %}
	    {% for message in messages %}
		{{ message }}
	    {% endfor %}
	{% endif %}
</p>
</form>
</div></div>
{% endblock %}
